@@ -1,16 +1,16 @@
-from hashlib import sha256
 import math
 import os
 import pathlib
 import re
+import sys
+from hashlib import sha256
 from urllib.parse import urlsplit
 
-
 DEFAULT_BLOCK_SIZE = 5 * 2 ** 20
 
 
 def infer_storage_options(urlpath, inherit_storage_options=None):
-    """ Infer storage options from URL path and merge it with existing storage
+    """Infer storage options from URL path and merge it with existing storage
     options.
 
     Parameters
@@ -30,8 +30,9 @@ def infer_storage_options(urlpath, inherit_storage_options=None):
     >>> infer_storage_options('/mnt/datasets/test.csv')  # doctest: +SKIP
     {"protocol": "file", "path", "/mnt/datasets/test.csv"}
     >>> infer_storage_options(
-    ...          'hdfs://username:pwd@node:123/mnt/datasets/test.csv?q=1',
-    ...          inherit_storage_options={'extra': 'value'})  # doctest: +SKIP
+    ...     'hdfs://username:pwd@node:123/mnt/datasets/test.csv?q=1',
+    ...     inherit_storage_options={'extra': 'value'},
+    ... )  # doctest: +SKIP
     {"protocol": "hdfs", "username": "username", "password": "pwd",
     "host": "node", "port": 123, "path": "/mnt/datasets/test.csv",
     "url_query": "q=1", "extra": "value"}
@@ -120,7 +121,7 @@ def infer_compression(filename):
 
 
 def build_name_function(max_int):
-    """ Returns a function that receives a single integer
+    """Returns a function that receives a single integer
     and returns it as a string padded by enough zero characters
     to align with maximum possible integer
 
@@ -198,7 +199,7 @@ def seek_delimiter(file, delimiter, blocksize):
 
 
 def read_block(f, offset, length, delimiter=None, split_before=False):
-    """ Read a block of bytes from a file
+    """Read a block of bytes from a file
 
     Parameters
     ----------
@@ -263,7 +264,7 @@ def read_block(f, offset, length, delimiter=None, split_before=False):
 
 
 def tokenize(*args, **kwargs):
-    """ Deterministic token
+    """Deterministic token
 
     (modified from dask.base)
 
@@ -279,7 +280,7 @@ def tokenize(*args, **kwargs):
 
 
 def stringify_path(filepath):
-    """ Attempt to convert a path-like object to a string.
+    """Attempt to convert a path-like object to a string.
 
     Parameters
     ----------
@@ -365,10 +366,31 @@ def is_exception(obj):
     return isinstance(obj, BaseException)
 
 
-def setup_logger(logname, level="DEBUG"):
+def get_protocol(url):
+    parts = re.split(r"(\:\:|\://)", url, 1)
+    if len(parts) > 1:
+        return parts[0]
+    return "file"
+
+
+def can_be_local(path):
+    """Can the given URL be used wih open_local?"""
+    from fsspec import get_filesystem_class
+
+    try:
+        return getattr(get_filesystem_class(get_protocol(path)), "local_file", False)
+    except (ValueError, ImportError):
+        # not in registry or import failed
+        return False
+
+
+def setup_logger(logname, level="DEBUG", clear=True):
+    """Add standard logging handler to logger of given name"""
     import logging
 
     logger = logging.getLogger(logname)
+    if clear:
+        logger.handlers.clear()
     handle = logging.StreamHandler()
     formatter = logging.Formatter(
         "%(asctime)s - %(name)s - %(levelname)s " "- %(message)s"
@@ -377,3 +399,39 @@ def setup_logger(logname, level="DEBUG"):
     logger.addHandler(handle)
     logger.setLevel(level)
     return logger
+
+
+def get_package_version_without_import(name):
+    """For given package name, try to find the version without importing it
+
+    Import and package.__version__ is still the backup here, so an import
+    *might* happen.
+
+    Returns either the version string, or None if the package
+    or the version was not readily  found.
+    """
+    if name in sys.modules:
+        mod = sys.modules[name]
+        if hasattr(mod, "__version__"):
+            return mod.__version__
+    if sys.version_info >= (3, 8):
+        try:
+            import importlib.metadata
+
+            return importlib.metadata.distribution(name).version
+        except ImportError:
+            pass
+    else:
+        try:
+            import importlib_metadata
+
+            return importlib_metadata.distribution(name).version
+        except ImportError:
+            pass
+    try:
+        import importlib
+
+        mod = importlib.import_module(name)
+        return mod.__version__
+    except (ImportError, AttributeError):
+        return None
